# node-litecoin

node-litecoin is a simple wrapper for the Litecoin client's JSON-RPC API.

The API is equivalent to the API document [here](https://en.bitcoin.it/wiki/Original_Bitcoin_client/API_Calls_list).
The methods are exposed as lower camelcase methods on the `litecoin.Client`
object.

## Install

`npm install litecoin`

## Setup

1. Traverse to `~/.litecoin` or `~/Library/Application Support/Litecoin` and add a file called `litecoin.conf` if it doesn't already exist.

2. Add these lines to the file:

    rpcuser=username

    rpcpassword=password

You will use these to login to the server.

3. Start your Litecoin client with the `-server` argument or run `litecoind`

4. You should now be able to communicate with Litecoin JSON-RPC API using the
node-litecoin library, try it out!

## Examples

### Create client
```js
var litecoin = require('litecoin');
var client = new litecoin.Client('localhost', 9332, 'username', 'password');
```

### Create client with single object
```js
var client = new litecoin.Client({
  host: 'localhost',
  port: 9332,
  username: 'username',
  password: 'password'
});
```

### Get balance across all accounts with minimum confirmations of 6

```js

client.getBalance('*', 6, function(err, balance) {
  if (err) console.log(err);
  console.log('Balance: ' + balance);
});
```

### Get the network hash rate

```js
client.getNetworkHashPS(function(err, hashps) {
  if (err) console.log(err);
  console.log('Network Hash Rate: ' + hashps);
});
```
